"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PushPaymentList = void 0;
const objects_1 = require("@hypernetlabs/objects");
const core_1 = require("@material-ui/core");
const styles_1 = require("@material-ui/core/styles");
const icons_1 = require("@material-ui/icons");
const contexts_1 = require("../../contexts");
const react_1 = __importDefault(require("react"));
const PushPaymentRow = (props) => {
    const { pushPayment, acceptPaymentButtonVisible, onAcceptPushPaymentClick, publicIdentifier, } = props;
    const [open, setOpen] = react_1.default.useState(false);
    const { viewUtils, dateUtils } = contexts_1.useStoreContext();
    const StyledTableRow = styles_1.withStyles((theme) => ({
        root: {
            "&:nth-of-type(odd)": {
                backgroundColor: theme.palette.action.hover,
            },
            "& > *": {
                borderBottom: "unset",
            },
        },
    }))(core_1.TableRow);
    const renderListItem = (label, value, hideDivider) => {
        return (react_1.default.createElement(core_1.Box, { margin: 2 },
            react_1.default.createElement(core_1.ListItem, null,
                react_1.default.createElement(core_1.Box, { display: "flex", justifyContent: "space-between", width: "100%" },
                    react_1.default.createElement(core_1.Typography, { style: { fontWeight: 600, fontSize: 14 } },
                        label,
                        ":"),
                    react_1.default.createElement(core_1.Typography, { style: { fontSize: 14 } }, value))),
            !hideDivider && react_1.default.createElement(core_1.Divider, null)));
    };
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement(StyledTableRow, null,
            react_1.default.createElement(core_1.TableCell, null,
                react_1.default.createElement(core_1.IconButton, { "aria-label": "expand row", size: "small", onClick: () => setOpen(!open) }, open ? react_1.default.createElement(icons_1.KeyboardArrowUp, null) : react_1.default.createElement(icons_1.KeyboardArrowDown, null))),
            react_1.default.createElement(core_1.TableCell, { component: "th", scope: "row" }, pushPayment.gatewayUrl),
            react_1.default.createElement(core_1.TableCell, { align: "right" }, viewUtils.fromBigNumberWei(pushPayment.paymentAmount)),
            react_1.default.createElement(core_1.TableCell, { align: "right" }, viewUtils.fromBigNumberWei(pushPayment.requiredStake)),
            react_1.default.createElement(core_1.TableCell, { align: "right" }, viewUtils.fromBigNumberWei(pushPayment.amountStaked)),
            react_1.default.createElement(core_1.TableCell, { align: "right" }, dateUtils.fromTimestampToUI(pushPayment.createdTimestamp)),
            react_1.default.createElement(core_1.TableCell, { align: "right" }, dateUtils.fromTimestampToUI(pushPayment.expirationDate)),
            react_1.default.createElement(core_1.TableCell, { align: "right", style: {
                    color: viewUtils.fromPaymentStateColor(pushPayment.state),
                } }, viewUtils.fromPaymentState(pushPayment.state)),
            react_1.default.createElement(core_1.TableCell, { align: "right" }, acceptPaymentButtonVisible && (react_1.default.createElement(core_1.Button, { size: "small", variant: "outlined", color: "primary", onClick: () => onAcceptPushPaymentClick(pushPayment.id) }, "Accept")))),
        react_1.default.createElement(core_1.TableCell, { style: { paddingBottom: 0, paddingTop: 0, borderBottom: "none" }, colSpan: 6 },
            react_1.default.createElement(core_1.Collapse, { in: open, timeout: "auto", unmountOnExit: true },
                react_1.default.createElement(core_1.Box, { marginBottom: 1 },
                    react_1.default.createElement(core_1.List, { dense: true },
                        renderListItem("Payment ID", pushPayment.id),
                        renderListItem("From", `${pushPayment.from} ${pushPayment.from === publicIdentifier ? "(You)" : ""}`),
                        renderListItem("To", `${pushPayment.to} ${pushPayment.to === publicIdentifier ? "(You)" : ""}`),
                        renderListItem("State", viewUtils.fromPaymentState(pushPayment.state)),
                        renderListItem("Payment Token", pushPayment.paymentToken),
                        renderListItem("Required Stake", viewUtils.fromBigNumberWei(pushPayment.requiredStake)),
                        renderListItem("Amount Staked	", viewUtils.fromBigNumberWei(pushPayment.amountStaked)),
                        renderListItem("Expiration Date", dateUtils.fromTimestampToUI(pushPayment.expirationDate)),
                        renderListItem("Created", dateUtils.fromTimestampToUI(pushPayment.createdTimestamp)),
                        renderListItem("Updated", dateUtils.fromTimestampToUI(pushPayment.updatedTimestamp)),
                        renderListItem("Gateway URL", pushPayment.gatewayUrl),
                        renderListItem("Payment Amount", viewUtils.fromBigNumberWei(pushPayment.paymentAmount), true)))))));
};
const PushPaymentList = (props) => {
    const { pushPayments, publicIdentifier, onAcceptPushPaymentClick } = props;
    return (react_1.default.createElement(core_1.TableContainer, null,
        react_1.default.createElement(core_1.Table, { "aria-label": "collapsible table" },
            react_1.default.createElement(core_1.TableHead, null,
                react_1.default.createElement(core_1.TableRow, null,
                    react_1.default.createElement(core_1.TableCell, null),
                    react_1.default.createElement(core_1.TableCell, null, "Gateway"),
                    react_1.default.createElement(core_1.TableCell, { align: "right" }, "Amount"),
                    react_1.default.createElement(core_1.TableCell, { align: "right" }, "Required Stake"),
                    react_1.default.createElement(core_1.TableCell, { align: "right" }, "Amount Staked"),
                    react_1.default.createElement(core_1.TableCell, { align: "right" }, "Created Date"),
                    react_1.default.createElement(core_1.TableCell, { align: "right" }, "Expiration Date"),
                    react_1.default.createElement(core_1.TableCell, { align: "right" }, "State"),
                    react_1.default.createElement(core_1.TableCell, { align: "right" }))),
            react_1.default.createElement(core_1.TableBody, null, pushPayments.map((pushPayment) => (react_1.default.createElement(PushPaymentRow, { key: pushPayment.id, pushPayment: pushPayment, publicIdentifier: publicIdentifier, acceptPaymentButtonVisible: publicIdentifier === pushPayment.to &&
                    pushPayment.state === objects_1.EPaymentState.Proposed, onAcceptPushPaymentClick: onAcceptPushPaymentClick })))))));
};
exports.PushPaymentList = PushPaymentList;
//# sourceMappingURL=PushPaymentList.js.map