"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useFund = void 0;
const objects_1 = require("@hypernetlabs/objects");
const contexts_1 = require("../contexts");
const objects_2 = require("../interfaces/objects");
const ethers_1 = require("ethers");
const react_1 = require("react");
const react_alert_1 = require("react-alert");
const constants_1 = require("../constants");
var EActionTypes;
(function (EActionTypes) {
    EActionTypes["FETCHED"] = "FETCHED";
    EActionTypes["TOKEN_SELECTED"] = "TOKEN_SELECTED";
    EActionTypes["SUCCESS"] = "SUCCESS";
    EActionTypes["ERROR"] = "ERROR";
    EActionTypes["AMOUNT_CHANGED"] = "AMOUNT_CHANGED";
    EActionTypes["DESTINATION_ADDRESS_CHANGED"] = "DESTINATION_ADDRESS_CHANGED";
})(EActionTypes || (EActionTypes = {}));
function useFund() {
    const { coreProxy } = contexts_1.useStoreContext();
    const { setLoading } = contexts_1.useLayoutContext();
    const alert = react_alert_1.useAlert();
    const initialState = {
        error: null,
        tokenSelectorOptions: [],
        selectedPaymentToken: undefined,
        amount: "1",
        destinationAddress: objects_1.EthereumAddress(""),
    };
    const [state, dispatch] = react_1.useReducer((state, action) => {
        switch (action.type) {
            case EActionTypes.FETCHED:
                return {
                    ...state,
                    error: false,
                    tokenSelectorOptions: action.payload,
                };
            case EActionTypes.TOKEN_SELECTED:
                return {
                    ...state,
                    error: false,
                    selectedPaymentToken: action.payload,
                };
            case EActionTypes.AMOUNT_CHANGED:
                return {
                    ...state,
                    error: false,
                    amount: action.payload,
                };
            case EActionTypes.DESTINATION_ADDRESS_CHANGED:
                return {
                    ...state,
                    error: false,
                    destinationAddress: action.payload,
                };
            case EActionTypes.ERROR:
                return {
                    ...state,
                    error: true,
                };
            case EActionTypes.SUCCESS:
                return {
                    ...state,
                    error: false,
                };
            default:
                return { ...state };
        }
    }, initialState);
    react_1.useEffect(() => {
        let cancelRequest = false;
        const fetchData = async () => {
            setLoading(true);
            try {
                if (cancelRequest)
                    return;
                // get data from coreProxy
                coreProxy === null || coreProxy === void 0 ? void 0 : coreProxy.getBalances().map((balance) => {
                    // prepare balances
                    setLoading(false);
                    dispatch({
                        type: EActionTypes.FETCHED,
                        payload: prepareTokenSelector(balance),
                    });
                });
                coreProxy.getEthereumAccounts().match((accounts) => {
                    dispatch({
                        type: EActionTypes.DESTINATION_ADDRESS_CHANGED,
                        payload: accounts[0],
                    });
                }, (err) => {
                    console.log("err: ", err);
                });
            }
            catch (error) {
                setLoading(false);
                if (cancelRequest)
                    return;
                dispatch({ type: EActionTypes.ERROR });
            }
        };
        fetchData();
        coreProxy === null || coreProxy === void 0 ? void 0 : coreProxy.onBalancesChanged.subscribe({
            next: (balance) => {
                if (cancelRequest)
                    return;
                dispatch({
                    type: EActionTypes.FETCHED,
                    payload: prepareTokenSelector(balance),
                });
            },
        });
        return function cleanup() {
            cancelRequest = true;
        };
    }, []);
    const prepareTokenSelector = (balance) => {
        // TODO: this should be pulled from metamask available balances not the channel balances
        //if (balance.assets.length) {
        if (false) {
            return balance.assets.reduce((acc, assetBalance) => {
                const tokenName = assetBalance.assetAddress === constants_1.ETHER_HEX_ADDRESS
                    ? "ETH"
                    : "HypernetToken";
                acc.push(new objects_2.PaymentTokenOptionViewModel(tokenName, assetBalance.assetAddress));
                return acc;
            }, new Array());
        }
        else {
            return [
                new objects_2.PaymentTokenOptionViewModel("HyperToken", objects_1.EthereumAddress("0x9FBDa871d559710256a2502A2517b794B482Db40")),
                new objects_2.PaymentTokenOptionViewModel("ETH", objects_1.EthereumAddress("0x0000000000000000000000000000000000000000")),
            ];
        }
    };
    const setSelectedPaymentToken = (selectedOption) => {
        dispatch({
            type: EActionTypes.TOKEN_SELECTED,
            payload: selectedOption,
        });
    };
    const setAmount = (enteredAmount) => {
        dispatch({
            type: EActionTypes.AMOUNT_CHANGED,
            payload: enteredAmount,
        });
    };
    const setDestinationAddress = (enteredAddress) => {
        dispatch({
            type: EActionTypes.AMOUNT_CHANGED,
            payload: objects_1.EthereumAddress(enteredAddress),
        });
    };
    const depositFunds = () => {
        var _a, _b;
        if (!((_a = state.selectedPaymentToken) === null || _a === void 0 ? void 0 : _a.address)) {
            dispatch({
                type: EActionTypes.ERROR,
            });
            return;
        }
        setLoading(true);
        coreProxy
            .depositFunds(objects_1.EthereumAddress(""), // TODO: Channel Address Here
        objects_1.EthereumAddress((_b = state.selectedPaymentToken) === null || _b === void 0 ? void 0 : _b.address), objects_1.BigNumberString(ethers_1.ethers.utils.parseEther(state.amount || "1").toString()))
            .match((balances) => {
            alert.success("Your fund deposit has succeeded!");
            setLoading(false);
            dispatch({
                type: EActionTypes.SUCCESS,
            });
        }, (err) => {
            alert.error(err.message || "Your fund deposit has failed");
            setLoading(false);
            dispatch({
                type: EActionTypes.ERROR,
            });
        });
    };
    const withdrawFunds = () => {
        var _a, _b;
        if (!((_a = state.selectedPaymentToken) === null || _a === void 0 ? void 0 : _a.address)) {
            dispatch({
                type: EActionTypes.ERROR,
            });
            return;
        }
        setLoading(true);
        coreProxy
            .withdrawFunds(objects_1.EthereumAddress(""), // TODO: Channel Address Here
        objects_1.EthereumAddress((_b = state.selectedPaymentToken) === null || _b === void 0 ? void 0 : _b.address), objects_1.BigNumberString(ethers_1.ethers.utils.parseEther(state.amount).toString()), state.destinationAddress)
            .match(() => {
            alert.success("Your funds withdrawl has succeeded!");
            setLoading(false);
            dispatch({
                type: EActionTypes.SUCCESS,
            });
        }, (err) => {
            alert.error(err.message || "Your funds withdrawl has failed");
            setLoading(false);
            dispatch({
                type: EActionTypes.ERROR,
            });
        });
    };
    const mintTokens = () => {
        setLoading(true);
        coreProxy
            .mintTestToken(objects_1.BigNumberString(ethers_1.ethers.utils.parseEther(state.amount || "1").toString()))
            .match(() => {
            alert.success("mint tokens has succeeded");
            setLoading(false);
            dispatch({
                type: EActionTypes.SUCCESS,
            });
        }, (err) => {
            alert.error(err.message || "mint tokens has failed");
            setLoading(false);
            dispatch({
                type: EActionTypes.ERROR,
            });
        });
    };
    return {
        ...state,
        setSelectedPaymentToken,
        setDestinationAddress,
        depositFunds,
        withdrawFunds,
        mintTokens,
        setAmount,
    };
}
exports.useFund = useFund;
//# sourceMappingURL=useFund.js.map